
import java.awt.*;
import javax.swing.*;
import sprite.*;

/**
 * A panel that shows a large red oval, that starts out in the
 * center of the panel.  The user can move the panel by pressing 
 * the up=, down-, left- and right-arrow keys.
 */
public class SpriteDemo2 extends SpritePanel {
	
	private OvalSprite oval; // The oval.
	
	/**
	 * Creates the panel, adds an oval to it, and sets up
	 * key handling.  The preferred size of the panel is 
	 * 400-by-400.
	 */
	public SpriteDemo2() {
		setPreferredSize( new Dimension(400,400) );
		oval = new OvalSprite(100,80, Color.RED);
		oval.setLocation(200,200);
		addSprite(oval);
		installKeyPress("Q");
		installKeyPress("LEFT");
		installKeyPress("RIGHT");
		installKeyPress("UP");
		installKeyPress("DOWN");
	}
	
	/**
	 * Respond to the arrow and Q keys.  (The constructor sets up
	 * the event-handler to send those key presses to this method.)
	 * The arrow keys will move the oval up, down, left and right.
	 * However, it is not allowed to move out of the panel.
	 */
	protected void doKeyPress( String keyStrokeString ) {
		int halfWidth = oval.getSpriteWidth() / 2;   // Half of the width of the oval.
		int halfHeight = oval.getSpriteHeight() / 2; // Half of the height of the oval.
		double x = oval.getX();  // x-position of the oval.
		double y = oval.getY();  // y-position of the oval.
		if (keyStrokeString.equals("LEFT")) {  // Move sprite left.
		    x = x - 10;
		    if (x - halfWidth < 0) {
		    	   // The left end of the oval (which is at x-halfWidth) is off the
		    	   // left end of the panel.  Set x so that the left end of the oval
		    	   // is just touching the left edge of the panel.
		    	x = halfWidth;
		    }
		    oval.setX(x);
		}
		else if (keyStrokeString.equals("RIGHT")) {  // Move sprite right.
		    x = x + 10;
		    if (x + halfWidth > getWidth()) {
		    	   // The right end of the oval (which is at x+halfWidth) is off the
		    	   // left end of the panel (which is at getWidth()).  Set x so that the
		    	   // right end of the oval is just touching the right edge of the panel.
		    	x = getWidth() - halfWidth;
		    }
		    oval.setX(x);
		}
		else if (keyStrokeString.equals("UP")) { // Move sprite up.
		    y = y - 10;
		    if (y - halfHeight < 0) {
		    	   // Adjust y so that the oval does not extend past the top of the panel.
		    	y = halfHeight;
		    }
		    oval.setY(y);
		}
		else if (keyStrokeString.equals("DOWN")) {  // Move sprite down.
		    y = y + 10;
		    if (y + halfHeight > getHeight()) {
		    	   // Adjust y so that the oval does not extend past the bottom of the panel.
		    	y = getHeight() - halfHeight;
		    }
		    oval.setY(y);
		}
		else if (keyStrokeString.equals("Q")) {  // Quit from the program.
			System.exit(0);
		}
	}
	
	/**
	 * This main routine makes it possible to run the class SpriteDemo2
	 * as an application.  (It has nothing to do with objects of type SpriteDemo2,
	 * and should perhaps be in another class.)  This routine opens a window
	 * that contains a panel of type SpriteDemo2.
	 */
	public static void main(String[] args) {
		JFrame window = new JFrame("Move It With Arrow Keys!");
		SpritePanel panel = new SpriteDemo2();
		window.setContentPane(panel);
		window.pack();
		window.setResizable(false);
		window.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
		Dimension screen = Toolkit.getDefaultToolkit().getScreenSize();
		window.setLocation( (screen.width - window.getWidth())/2, 
				(screen.height - window.getHeight())/2 );
		window.setVisible(true);
		// panel.go(); There is no animation in this program, so panel.go() is not needed.
	}

}
