package sprite;

import java.awt.*;
import java.awt.image.BufferedImage;
import javax.imageio.ImageIO;

/**
 * A sprite that displays an image.  The position of the sprite gives
 * the center of the image.
 */
public class ImageSprite extends Sprite {
	
	private BufferedImage image;

	/**
	 * Create an ImageSprite to display a given image.
	 * The width and height of the sprite are set to match the width and height
	 * of the image, and they should not be changed.
	 * @param imageResource give the name of the image file.  The image file
	 * must be part of the program.  If the file is in a folder, then the folder
	 * name must be part of the image name.  For example:  "images/earth.png".  PNG
	 * and JPEG images, at least, are supported (with file extensions .png, .jpg, .jpeg).
	 */
	public ImageSprite(String imageResource) {
		try {
			image = ImageIO.read(getClass().getClassLoader().getResource(imageResource));
			setSpriteWidth(image.getWidth());
			setSpriteHeight(image.getHeight());
		}
		catch (Exception e) {
			image = null;
		}
	}
	
	public ImageSprite(String imageResource, boolean isOval) {
		try {
			image = ImageIO.read(getClass().getClassLoader().getResource(imageResource));
			setSpriteWidth(image.getWidth());
			setSpriteHeight(image.getHeight());
			setUseOvalForContains(isOval);
		}
		catch (Exception e) {
			image = null;
		}
	}
	
	public void draw(Graphics g) {
		int centerX = (int)getX();
		int centerY = (int)getY();
		if (image == null)
			g.drawString("ERROR: NO IMAGE", centerX, centerY);
		else
			g.drawImage(image,centerX - image.getWidth()/2, centerY - image.getHeight()/2, null);
	}
	
}
