package sprite;

import java.awt.*;

/**
 * A simple sprite which is filled, colored oval whose width and height are equal to the
 * width and height of the sprite.  The position of the sprite is the center of the oval.
 */
public class OvalSprite extends Sprite {
	
	private Color color;
	
	/**
	 * Creates a black oval.
	 * @param w the width of the oval.
	 * @param h the height of the oval.
	 */
	public OvalSprite(int w, int h) {
		setSpriteWidth(w);
		setSpriteHeight(h);
		color = Color.BLACK;
		setUseOvalForContains(true);
	}
	
	/**
	 * Creates a colored oval.
	 * @param w the width of the oval.
	 * @param h the height of the oval.
	 * @param color the color of the sprite.  If this is null, then the sprite is black.
	 */
	public OvalSprite(int w, int h, Color c) {
		setSpriteWidth(w);
		setSpriteHeight(h);
		setColor(c);
		setUseOvalForContains(true);
	}
	
	public void draw(Graphics g) { 
		int centerX = (int)getX();
		int centerY = (int)getY();
		g.setColor(color);
		g.fillOval( centerX - getSpriteWidth()/2, 
				centerY - getSpriteHeight()/2, getSpriteWidth(), getSpriteHeight() );
	}

	public Color getColor() {
		return color;
	}

	/**
	 * Sets the color of the sprite.  If the color is null, then the
	 * default color, black, is used.
	 */
	public void setColor(Color c) {
		if (c == null)
			color = Color.BLACK;
		else 
			color = c;
	}
	
}
