package sprite;

import java.awt.*;

/**
 * A sprite that represents a gun.  The gun can shoot Bullet sprites.  The gun is
 * shown as a blue ball with a gun barrel sticking out of it.  The barrel points
 * in the direction that bullets will be shot.
 */
public class SimpleGun extends Sprite {
	
	private double angle;
	private double bulletSpeed;
	
	/**
	 * Creates a gun whose barrel initially points up.  It shoots bullets that
	 * have a speed of 10.
	 */
	public SimpleGun() {
		angle = 0;
		bulletSpeed = 10;
	}
	
	public void draw(Graphics g) {
		int x = (int)getX();
		int y = (int)getY();
		g.setColor(Color.DARK_GRAY);
		((Graphics2D)g).setStroke(new BasicStroke(6));
		double radians = (angle-90)/180 * Math.PI;
		g.drawLine( x, y, x + (int)(20*Math.cos(radians)), (int)(y + 20*Math.sin(radians)) );
		g.setColor(Color.BLUE);
		g.fillOval(x-10,y-10,20,20);
	}
	
	/**
	 * Fire a bullet by adding a Bullet sprite to the panel that contains this GunSprite.
	 * The bullet's speed is given by the gun's bulletSpeed property.  The direction of
	 * the bullet is given by the direction the gun is pointing.  (If the gun is not in
	 * a panel, this method does nothing.)
	 */
	public void fire() {
		if (getHome() == null)
			return;
		double radians = (angle-90)/180 * Math.PI;
		double startX = getX() + 10*Math.cos(radians);
		double startY = getY() + 10*Math.sin(radians);
		Bullet b = new Bullet(startX, startY, 
				bulletSpeed*Math.cos(radians), bulletSpeed*Math.sin(radians) );
		getHome().addSprite(b);
	}

	public double getAngle() {
		return angle;
	}

	/**
	 * Sets the direction that the gun is pointing.  The angle is given in degrees,
	 * with zero degrees pointing up.  Positive angles are measured clockwise from
	 * that position; negative angles, counterclockwise.
	 */
	public void setAngle(double degrees) {
		angle = degrees;
	}

	public double getBulletSpeed() {
		return bulletSpeed;
	}

	/**
	 * Sets the speed for bullets fired by this gun.
	 */
	public void setBulletSpeed(double speed) {
		this.bulletSpeed = speed;
	}

}
